@@ -14,7 +14,7 @@ mainwindow::mainwindow(QWidget *parent) :
 
     ui->setupUi(this);
 
-    if (QFile::exists("/opt/cssutransitionstuner/cssuinstalled")) {
+    if (!QFile::exists("/opt/cssutransitionstuner/cssuinstalled")) {
         QMaemo5InformationBox::information(this, tr("Could not detect Community SSU being installed.<br /><br />You may still try to use the CSSU Tuner, but some functions may not have effect."), QMaemo5InformationBox::NoTimeout);
     }
 
@@ -28,7 +28,7 @@ mainwindow::mainwindow(QWidget *parent) :
     orientationChanged();
     readvalues();
     abouttext = tr("Author: d-iivil<br />Licence: GPL");
-    abouttitle = "CSSU Tuner " + tr("version") + " 0.1.8";
+    abouttitle = "CSSU Tuner " + tr("version") + " 0.1.9";
 }
 
 mainwindow::~mainwindow()
